@@ -9,8 +9,6 @@
 #include "linglong/builder/linglong_builder.h"
 #include "linglong/cli/cli.h"
 
-#include <filesystem>
-#include <optional>
 #include <string>
 #include <vector>
 
@@ -40,12 +38,13 @@ struct ListCommandOptions
 
 struct RemoveCommandOptions
 {
+    bool noCleanObjects = false;
     std::vector<std::string> removeList; // List of apps to remove
 };
 
 struct ExportCommandOptions
 {
-    linglong::builder::ExportOption exportSpecificOptions{ .exportI18n = true };
+    linglong::builder::ExportOption exportSpecificOptions;
     bool layerMode = false;
     std::string outputFile;
 };
