@@ -10,9 +10,16 @@
 
 namespace linglong::api::types::v1 {
 
+// I added this size assertion because these structs overload == operator.
+// Adding new fields will make this fail, reminding me to update the == implementation.
+static_assert(sizeof(struct Repo) == 120);
+static_assert(sizeof(struct RepoConfig) == 88);
+static_assert(sizeof(struct RepoConfigV2) == 64);
+
 inline bool operator==(const Repo &cfg1, const Repo &cfg2) noexcept
 {
-    return cfg1.alias == cfg2.alias && cfg1.name == cfg2.name && cfg1.url == cfg2.url && cfg1.priority == cfg2.priority;
+    return cfg1.alias == cfg2.alias && cfg1.name == cfg2.name && cfg1.url == cfg2.url
+      && cfg1.priority == cfg2.priority && cfg1.mirrorEnabled == cfg2.mirrorEnabled;
 }
 
 inline bool operator!=(const Repo &cfg1, const Repo &cfg2) noexcept
