@@ -4,13 +4,12 @@
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
-#ifndef LINGLONG_API_V1_DBUS_PACKAGEMANAGER1_H_
-#define LINGLONG_API_V1_DBUS_PACKAGEMANAGER1_H_
+#pragma once
 
 #include "linglong/api/dbus/v1/gen_org_deepin_linglong_packagemanager1.h"
 
 namespace linglong::api::dbus::v1 {
-using PackageManager = OrgDeepinLinglongPackageManager1Interface;
-}
 
-#endif
+using PackageManager = OrgDeepinLinglongPackageManager1Interface;
+
+}
